selectiontools.SliceSelection
=============================

.. abjad-lineage:: abjad.tools.selectiontools.SliceSelection.SliceSelection

.. autoclass:: abjad.tools.selectiontools.SliceSelection.SliceSelection

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.get_duration
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.get_spanners
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.get_timespan
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.group_by
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations_exactly
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations_not_greater_than
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations_not_less_than
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__add__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__contains__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__eq__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__format__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__getitem__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__hash__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__illustrate__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__len__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__ne__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__radd__
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection.__repr__

Bases
-----

- :py:class:`selectiontools.ContiguousSelection <abjad.tools.selectiontools.ContiguousSelection.ContiguousSelection>`

- :py:class:`selectiontools.Selection <abjad.tools.selectiontools.Selection.Selection>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.get_duration
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.get_spanners
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.get_timespan
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.group_by
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations_exactly
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations_not_greater_than
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.partition_by_durations_not_less_than
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__add__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__contains__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__eq__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__format__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__getitem__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__hash__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__illustrate__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__len__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__ne__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__radd__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SliceSelection.SliceSelection.__repr__
   :noindex:
